37#include <hip/hip_runtime.h>
45 void *m_x,
void *m_y,
void *m_z,
49 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
64 void *
u,
void *
v,
void *
w,
void *
E,
65 void *rho,
real *gamma,
int *n) {
68 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
83 real *gamma,
int *n) {
86 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
99 real *gamma,
int *n) {
102 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
114 void *dudx,
void *dudy,
void *dudz,
115 void *dvdx,
void *dvdy,
void *dvdz,
116 void *dwdx,
void *dwdy,
void *dwdz,
120 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
136 void *
visc_E,
void *f_x,
void *f_y,
void *f_z,
138 void *
u,
void *
v,
void *
w,
void *B,
142 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
158 void *kappa,
real *gamma,
int *n) {
161 const dim3 nblcks(((*n) + 1024 - 1) / 1024, 1, 1);
167 (
real *) rho, (
real *) kappa, *gamma, *n);
void hip_ns_flux_finalize(void *visc_m_x, void *visc_m_y, void *visc_m_z, void *visc_E, void *f_x, void *f_y, void *f_z, void *opgrad_x, void *opgrad_y, void *opgrad_z, void *u, void *v, void *w, void *B, void *dissipation, int *n)
void hip_update_temperature(void *T, void *p, void *rho, real *gamma, int *n)
void hip_ns_flux_prepare(void *div_flux, void *dissipation, void *h1, void *dudx, void *dudy, void *dudz, void *dvdx, void *dvdy, void *dvdz, void *dwdx, void *dwdy, void *dwdz, void *mu, int *n)
void hip_update_e(void *E, void *p, void *ruvw, real *gamma, int *n)
void hip_ns_flux_temperature(void *div_flux, void *h1, void *p, void *rho, void *kappa, real *gamma, int *n)
void hip_update_uvw(void *u, void *v, void *w, void *m_x, void *m_y, void *m_z, void *rho, int *n)
void hip_update_mxyz_p_ruvw(void *m_x, void *m_y, void *m_z, void *p, void *ruvw, void *u, void *v, void *w, void *E, void *rho, real *gamma, int *n)
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ w
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ v
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ h1